.. Johnny Can Encrypt documentation master file, created by
   sphinx-quickstart on Wed Jul  8 18:19:32 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Johnny Can Encrypt's documentation!
==============================================

This is a Python module providing encryption and decryption operations based on OpenPGP. It
uses `sequoia-pgp <https://sequoia-pgp.org>`_ project for the actual operations. This does not
depend on the existing `gpg` tooling.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   build
   introduction
   api
   rustimplementation
   smartcard


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
